local en_popup = require("ui/data/keyboardlayouts/keypopup/en_popup")
local com = en_popup.com -- comma (,)
local prd = en_popup.prd -- period (.)
local _at = en_popup._at
local _eq = en_popup._eq -- equals sign (=)

return {
    min_layer = 1,
    max_layer = 8,
    shiftmode_keys = {[""] = true},
    symbolmode_keys = {["Sym"] = true, ["ABC"] = true},
    utf8mode_keys = {["🌐"] = true},
    umlautmode_keys = {["Äéß"] = true},
    keys = {
        -- first row
        {  --  1       2       3       4       5       6       7       8
            { "Й",    "й",    "„",    "0",    "?",    "!",    "1",    "ª", },
            { "Ц",    "ц",    "!",    "1",    "(",    "1",    "2",    "º", },
            { "У",    "у",    _at,    "2",    ")",    "2",    "3",    "¡", },
            { "К",    "к",    "#",    "3",    "~",    "3",    "4",    "¿", },
            { "Е",    "е",     "+",    _eq,   "Ә",    "ә",    "5",    "¼", },
            { "Н",    "н",    "€",    "(",    "І",    "і",    "6",    "½", },
            { "Г",    "г",    "‰",    ")",    "Ң",    "ң",    "7",    "¾", },
            { "Ш",    "ш",    "|",   "\\",    "Ғ",    "ғ",    "8",    "©", },
            { "Щ",    "щ",    "?",    "/",    "Х",    "х",    "9",    "®", },
            { "З",    "з",    "~",    "`",    "Ъ",    "ъ",    "0",    "™", },
        },
        -- second row
        {  --  1       2       3       4       5       6       7       8
            { "Ф",    "ф",    "…",    _at,    "*",    "0",    "Ş",    "ş", },
            { "Ы",    "ы",    "$",    "4",    "+",    "4",    "İ",    "ı", },
            { "В",    "в",    "%",    "5",    "-",    "5",    "Ğ",    "ğ", },
            { "А",    "а",    "^",    "6",    _eq,    "6",    "Ć",    "ć", },
            { "П",    "п",    ":",    ";",    "Ү",    "ү",    "Č",    "č", },
            { "Р",    "р",    '"',    "'",    "Ұ",    "ұ",    "Đ",    "đ", },
            { "О",    "о",    "{",    "[",    "Қ",    "қ",    "Š",    "š", },
            { "Л",    "л",    "}",    "]",    "Ж",    "ж",    "Ž",    "ž", },
            { "Д",    "д",    "_",    "-",    "Э",    "э",    "Ő",    "ő", },
        },
        -- third row
        {  --  1       2       3       4       5       6       7       8
            { label = "",
              width = 1.5
            },
            { "Я",    "я",    "&",    "7",    ":",    "7",    "Ű",    "ű", },
            { "Ч",    "ч",    "*",    "8",    ";",    "8",    "Ã",    "ã", },
            { "С",    "с",    "£",    "9",    "'",    "9",    "Þ",    "þ", },
            { "М",    "м",    "<",    com,    "Ө",    "ө",    "Ý",    "ý", },
            { "И",    "и",    ">",    prd,    "Һ",    "һ",    "†",    "‡", },
            { "Т",    "т",    "‘",    "↑",    "Б",    "б",    "–",    "—", },
            { "Ь",    "ь",    "’",    "↓",    "Ю",    "ю",    "…",    "¨", },
            { label = "Backspace",
              icon = "resources/icons/appbar.clear.reflect.horizontal.png",
              width = 1.5
            },
        },
        -- fourth row
        {
            { "Sym",  "Sym",  "ABC",  "ABC",  "ABC",  "ABC",  "Sym",  "Sym",  "ABC",  "ABC",
              width = 1.5},
            { label = "🌐", },
            { "Äéß",  "Äéß",  "Äéß",  "Äéß",  "Äéß",  "Äéß",  "Äéß",  "Äéß",  "Äéß",  "Äéß", },
            { label = "space",
              " ",        " ",    " ",    " ",   " ",    " ",    " ",    " ",    " ",    " ",
              width = 3.0},
            { com,    com,    "“",    "←",    "Ё",    "ё",    "Ũ",   "ũ",    com,    com, },
            { prd,    prd,    "”",    "→",    prd,    prd,    "Ĩ",   "ĩ",    prd,    prd, },
            { label = "Enter",
              "\n",   "\n",   "\n",   "\n",   "\n",   "\n",   "\n",   "\n",   "\n",   "\n",
              icon = "resources/icons/appbar.arrow.enter.png",
              width = 1.5,
            },
        },
    },
}
